@@ -29,6 +29,14 @@ API_SERVICE_OPTS = [
                default=1000,
                help=_('The maximum number of items returned in a single '
                       'response from a collection resource.')),
+    cfg.StrOpt('public_endpoint',
+               default=None,
+               help=_("Public URL to use when building the links to the API "
+                      "resources (for example, \"https://ironic.rocks:6384\")."
+                      " If None the links will be built using the request's "
+                      "host URL. If the API is operating behind a proxy, you "
+                      "will want to change this to represent the proxy's URL. "
+                      "Defaults to None.")),
 ]
 
 CONF = cfg.CONF
