@@ -370,6 +370,9 @@ def setup_vmedia_for_boot(task, bootable_iso_filename, parameters=None):
     LOG.info(_LI("Setting up node %s to boot from virtual media"),
              task.node.uuid)
 
+    _detach_virtual_cd(task.node)
+    _detach_virtual_fd(task.node)
+
     if parameters:
         floppy_image_filename = _prepare_floppy_image(task, parameters)
         _attach_virtual_fd(task.node, floppy_image_filename)
@@ -599,7 +602,7 @@ class IRMCVirtualMediaIscsiDeploy(base.DeployInterface):
         iscsi_deploy.check_image_size(task)
 
         deploy_ramdisk_opts = iscsi_deploy.build_deploy_ramdisk_options(node)
-        agent_opts = agent.build_agent_options(node)
+        agent_opts = deploy_utils.build_agent_options(node)
         deploy_ramdisk_opts.update(agent_opts)
         deploy_nic_mac = deploy_utils.get_single_nic_with_vif_port_id(task)
         deploy_ramdisk_opts['BOOTIF'] = deploy_nic_mac
@@ -703,7 +706,7 @@ class IRMCVirtualMediaAgentDeploy(base.DeployInterface):
             image.
         :raises: IRMCOperationError, if some operation on iRMC fails.
         """
-        deploy_ramdisk_opts = agent.build_agent_options(task.node)
+        deploy_ramdisk_opts = deploy_utils.build_agent_options(task.node)
         _reboot_into_deploy_iso(task, deploy_ramdisk_opts)
 
         return states.DEPLOYWAIT
@@ -909,3 +912,17 @@ class VendorPassthru(agent_base_vendor.BaseAgentVendor):
             self._configure_vmedia_boot(task, root_uuid)
 
         self.reboot_and_finish_deploy(task)
+
+
+class IRMCVirtualMediaAgentVendorInterface(agent.AgentVendorInterface):
+    """Interface for vendor passthru related actions."""
+
+    def reboot_to_instance(self, task, **kwargs):
+        node = task.node
+        LOG.debug('Preparing to reboot to instance for node %s',
+                  node.uuid)
+
+        _cleanup_vmedia_boot(task)
+
+        super(IRMCVirtualMediaAgentVendorInterface,
+              self).reboot_to_instance(task, **kwargs)
