@@ -20,6 +20,7 @@ import os
 import tempfile
 import time
 
+from glanceclient import client as glance_client
 from glanceclient import exc as glance_exc
 import mock
 from oslo_config import cfg
@@ -600,28 +601,44 @@ class TestGlanceImageService(base.TestCase):
         wrapped_func = base_image_service.check_image_service(func)
         self.assertTrue(wrapped_func(self.service))
 
-    def test_check_image_service__no_client_set_http(self):
+    @mock.patch.object(glance_client, 'Client', autospec=True)
+    def test_check_image_service__no_client_set_http(self, mock_gclient):
         def func(service, *args, **kwargs):
             return (self.endpoint, args, kwargs)
 
+        endpoint = 'http://123.123.123.123:9292'
+        mock_gclient.return_value.endpoint = endpoint
         self.service.client = None
-        params = {'image_href': 'http://123.123.123.123:9292/image_uuid'}
+
+        params = {'image_href': '%s/image_uuid' % endpoint}
         self.config(auth_strategy='keystone', group='glance')
         wrapped_func = base_image_service.check_image_service(func)
-        self.assertEqual(('http://123.123.123.123:9292', (), params),
+        self.assertEqual((endpoint, (), params),
                          wrapped_func(self.service, **params))
+        mock_gclient.assert_called_once_with(
+            1, endpoint,
+            **{'insecure': CONF.glance.glance_api_insecure,
+               'token': self.context.auth_token})
 
-    def test_get_image_service__no_client_set_https(self):
+    @mock.patch.object(glance_client, 'Client', autospec=True)
+    def test_get_image_service__no_client_set_https(self, mock_gclient):
         def func(service, *args, **kwargs):
             return (self.endpoint, args, kwargs)
 
+        endpoint = 'https://123.123.123.123:9292'
+        mock_gclient.return_value.endpoint = endpoint
         self.service.client = None
-        params = {'image_href': 'https://123.123.123.123:9292/image_uuid'}
+
+        params = {'image_href': '%s/image_uuid' % endpoint}
         self.config(auth_strategy='keystone', group='glance')
         wrapped_func = base_image_service.check_image_service(func)
 
-        self.assertEqual(('https://123.123.123.123:9292', (), params),
+        self.assertEqual((endpoint, (), params),
                          wrapped_func(self.service, **params))
+        mock_gclient.assert_called_once_with(
+            1, endpoint,
+            **{'insecure': CONF.glance.glance_api_insecure,
+               'token': self.context.auth_token})
 
 
 def _create_failing_glance_client(info):
